####

1 | Class@0@ | Delivering Power

Output Voltage (V)

54

Fault Status

No Error

Output Current (mA)

30

Output Power (W)

1.6

Temperature (℃)

30

####

2 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

3 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

4 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

32

####

5 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

32

####

6 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

7 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

8 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

9 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

10 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

11 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

12 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

29

####

13 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

14 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30

####

15 | Unknown | Searching

Output Voltage (V)

0

Fault Status

No Error

Output Current (mA)

0

Output Power (W)

0.0

Temperature (℃)

30